@@ -324,7 +324,7 @@ queries until after they have been run.
 =cut
 
 package Test::DBIC::ExpectedQueries;
-$Test::DBIC::ExpectedQueries::VERSION = '1.009';
+$Test::DBIC::ExpectedQueries::VERSION = '1.010';
 use Moo;
 use Exporter::Tiny;
 BEGIN {extends "Exporter::Tiny"};
@@ -430,7 +430,7 @@ sub _stack_trace {
 
     my $trace = Devel::StackTrace->new(
         message      => "executed",
-        ignore_class => @{$self->ignore_classes},
+        ignore_class => $self->ignore_classes,
     );
 
     my $callers = $trace->as_string;
